@@ -68,7 +68,8 @@ gucharmap_get_unicode_name (gunichar wc)
   if ((wc >= 0x3400 && wc <= 0x4DB5)
       || (wc >= 0x4e00 && wc <= 0x9fcb)
       || (wc >= 0x20000 && wc <= 0x2A6D6)
-      || (wc >= 0x2a700 && wc <= 0x2b734))
+      || (wc >= 0x2a700 && wc <= 0x2b734)
+      || (wc >= 0x2b740 && wc <= 0x2b81d))
     {
       g_snprintf (buf, sizeof (buf), "CJK UNIFIED IDEOGRAPH-%04X", wc);
       return buf;
@@ -393,8 +394,13 @@ gucharmap_get_nameslist_exes (gunichar uc)
   return exes;
 }
 
-/* returns newly allocated null-terminated array of gchar* */
-/* the items are const, but the array should be freed by the caller */
+/**
+ * gucharmap_get_nameslist_equals:
+ * @uc: a gunichar
+ *
+ * Returns: (transfer container): newly allocated null-terminated array of gchar*
+ * the items are const, but the array should be freed by the caller
+ */
 G_CONST_RETURN gchar **
 gucharmap_get_nameslist_equals (gunichar uc)
 {
@@ -419,8 +425,13 @@ gucharmap_get_nameslist_equals (gunichar uc)
   return equals;
 }
 
-/* returns newly allocated null-terminated array of gchar* */
-/* the items are const, but the array should be freed by the caller */
+/**
+ * gucharmap_get_nameslist_stars:
+ * @uc: a #gunichar
+ *
+ * Returns: (transfer container): newly allocated null-terminated array of gchar*
+ * the items are const, but the array should be freed by the caller
+ */
 G_CONST_RETURN gchar **
 gucharmap_get_nameslist_stars (gunichar uc)
 {
@@ -445,8 +456,13 @@ gucharmap_get_nameslist_stars (gunichar uc)
   return stars;
 }
 
-/* returns newly allocated null-terminated array of gchar* */
-/* the items are const, but the array should be freed by the caller */
+/**
+ * gucharmap_get_nameslist_pounds:
+ * @uc: a #gunichar
+ *
+ * Returns: (transfer container): newly allocated null-terminated array of gchar*
+ * the items are const, but the array should be freed by the caller
+ */
 G_CONST_RETURN gchar **
 gucharmap_get_nameslist_pounds (gunichar uc)
 {
@@ -471,8 +487,13 @@ gucharmap_get_nameslist_pounds (gunichar uc)
   return pounds;
 }
 
-/* returns newly allocated null-terminated array of gchar* */
-/* the items are const, but the array should be freed by the caller */
+/**
+ * gucharmap_get_nameslist_colons:
+ * @uc: a #gunichar
+ *
+ * Returns: (transfer container): newly allocated null-terminated array of gchar*
+ * the items are const, but the array should be freed by the caller
+ */
 G_CONST_RETURN gchar **
 gucharmap_get_nameslist_colons (gunichar uc)
 {
@@ -559,7 +580,7 @@ gucharmap_unichar_to_printable_utf8 (gunichar uc, gchar *outbuf)
 
 /**
  * gucharmap_unichar_type:
- * @c: a Unicode character
+ * @uc: a Unicode character
  * 
  * Classifies a Unicode character by type.
  * 
